<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation type="unfinished">Taglia (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation type="unfinished">Copia (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation type="unfinished">Incolla (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation type="unfinished">Annulla (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation type="unfinished">Refai (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation type="unfinished">Potenza (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation type="unfinished">Parentesi </translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation type="unfinished">Valore assoluto</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation type="unfinished">Frazione (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation type="unfinished">Radice (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation type="unfinished">Distanza {%1} {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation type="unfinished">Circonferenza {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation type="unfinished">Lunghezza {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation type="unfinished">Raggio {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation type="unfinished">Arco Angolo {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation type="unfinished">Angolo {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation type="unfinished">Rapporto {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation type="unfinished">Pendenza {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation type="unfinished">Area {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation type="unfinished">Punto</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation type="unfinished">Segmento</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation type="unfinished">Raggio</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished">Linea</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished">Cerchio</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation type="unfinished">Arco</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished">Poligono</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation type="unfinished">Cerchio Interno</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation type="unfinished">Settore dell&apos;Arco</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation type="unfinished">Segmento Circolare</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation type="unfinished">Luogo</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation type="unfinished">Misura</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation type="unfinished">Calcolo</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation type="unfinished">Annotazione</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Incognito</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation type="unfinished">indefinito</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation type="unfinished">Il Valore e&apos; indefinito</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation type="unfinished">Il Valore e&apos; %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation type="unfinished">Inserisci %1 %2</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Pronto</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation type="unfinished">Ciclo su %1</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">o</translation>
    </message>
    <message>
        <source>final</source>
        <translation type="unfinished">finale</translation>
    </message>
    <message>
        <source>initial</source>
        <translation type="unfinished">iniziale</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation type="unfinished">non construito</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation type="unfinished">non esiste</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation type="unfinished">nascosto</translation>
    </message>
    <message>
        <source>Given</source>
        <translation type="unfinished">Dato</translation>
    </message>
    <message>
        <source>Final</source>
        <translation type="unfinished">Finale</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation type="unfinished">Iniziale</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation type="unfinished">%1 e&apos; la traslazione di %2 del vettore da %3 a %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation type="unfinished">%1 e&apos; la rotazione di %2 su %3 con angolo %4</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation type="unfinished">%1 e&apos; l&apos;immagine di %2 in scala su %3 di rapporto %4:%5</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation type="unfinished">%1 e&apos; l&apos;immagine di %2 di scala %3 con rapporto %4</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation type="unfinished">%1 e&apos; la riflessione di %2 su %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation type="unfinished">%1 e&apos; libero</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation type="unfinished">%1 e&apos; su %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation type="unfinished">%1 e&apos; l&apos;intersezione di %2 e %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation type="unfinished">%1 e&apos; la seconda intersezione di %2 e %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation type="unfinished">%1 e&apos; il punto medio di %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation type="unfinished">%1 ha vertici %2 e %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation type="unfinished">%1 e&apos; da %2 attraverso %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation type="unfinished">%1 biseca l&apos;angolo %2 %3 %4</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation type="unfinished">%1 e&apos; tra %2 e %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation type="unfinished">%1 e&apos; parallelo a %2 per %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation type="unfinished">%1 e&apos; perpendicolare a %2 per %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation type="unfinished">%1 e&apos; centrato in %2 e passa per %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation type="unfinished">%1 ha il centro in %2 e raggio %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation type="unfinished">%1 passa per i punti %2, %3, e %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation type="unfinished">%1 e&apos; tracciata con %2, condotta per %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation type="unfinished">%1 involve %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation type="unfinished">%1 e&apos; la distanza tra %2 e %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation type="unfinished">%1 e&apos; la lunghezza di %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation type="unfinished">%1 e&apos; l&apos;angolo di %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation type="unfinished">%1 e&apos; l&apos;angolo tra i punti %1, %2, e %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation type="unfinished">%1 e&apos; il rapporto di %2 a %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation type="unfinished">%1 e&apos; la pendenza di %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation type="unfinished">%1 e&apos; l&apos;area di %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation type="unfinished">%1 e&apos; definito da %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation type="unfinished">%1 ha i vertici nei punti %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation type="unfinished">%1 e&apos; il raggio di %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation type="unfinished">%1 e&apos; il punto finale di %2</translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation type="unfinished">%1 e&apos; il secondo punto finale di %2</translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation type="unfinished">%1 e&apos; il centro di %2</translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation type="unfinished">Preferenze KSEG</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation type="unfinished">Colore di sfondo</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation type="unfinished">Colore di rilievo di default</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation type="unfinished">Visualizza la Selezione</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation type="unfinished">Bordo dei selezionati</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation type="unfinished">Lampeggio dei Selezionati</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation type="unfinished">Profondita&apos; della ricorsione:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation type="unfinished">Produrra&apos; troppi oggetti.</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation type="unfinished">Produrra&apos; %1 oggetti.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation type="unfinished">Elementi nel luogo:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation type="unfinished">Seleziona</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation type="unfinished">Deseleziona</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation type="unfinished">Nuovo Gruppo</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation type="unfinished">Cancella il Gruppo</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Chiudi</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation type="unfinished">Azione
sugli elementi
invisibili</translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation type="unfinished">Premi SHIFT e clicca per aggiungere la selezione attuale</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation type="unfinished">Nei gruppi &quot;Tutti &lt;Tipo&gt;&quot;  (de)selezionare anche gli oggetti invisibili</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation type="unfinished">Tutti i punti</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation type="unfinished">Tutti i segmenti</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation type="unfinished">Tutte le semirette</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation type="unfinished">Tutte le rette</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation type="unfinished">Tutti i cerchi</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation type="unfinished">Tutti gli archi</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation type="unfinished">Tutti i poligoni</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation type="unfinished">Tutti gli interni del cerchio</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation type="unfinished">Tutti i Settori circolari</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation type="unfinished">Tutti i Segmenti circolari</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation type="unfinished">Tutti i luoghi</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation type="unfinished">Tutte le Misure</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation type="unfinished">Tutti i Calcoli</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation type="unfinished">Introduci il nome del nuovo gruppo:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation type="unfinished">Sei certo di voler cancellare il gruppo(i) selezionato(i)?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation type="unfinished">Senza titolo</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Pronto</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation type="unfinished">Muovi l&apos;etichetta di %1 %2</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation type="unfinished">Seleziona %1 %2</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation type="unfinished">Deseleziona %1 %2</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation type="unfinished">Seleziona anche %1 %2</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation type="unfinished">Muovi gli oggetti selezionati</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation type="unfinished">Rivincola %1 %2 ad essere libero</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation type="unfinished">Rivincola %1 %2 a %3 %4</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation type="unfinished">Rivincola %1 %2 all&apos; intersezione di %3 %4 e %5 %6</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation type="unfinished">Sposta</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Zoom</translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation type="unfinished">kseg: Senza titolo</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;File</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Edita</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nuovo</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation type="unfinished">Mis&amp;ura</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation type="unfinished">&amp;Trasformazione</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation type="unfinished">Esegui</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation type="unfinished">Cost&amp;ruzione</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Help</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation type="unfinished">&amp;Nuovo Schema</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation type="unfinished">Nuova Costruzione</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation type="unfinished">Nuovo &amp;Vista</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished">&amp;Apri...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished">&amp;Salva</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished">Salva &amp;Come...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished">&amp;Stampa...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation type="unfinished">Scegli &amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Chiudi</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Esci</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation type="unfinished">&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation type="unfinished">&amp;Rifai</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation type="unfinished">&amp;Cancella oggetti</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation type="unfinished">Inverti &amp;Etichetta</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation type="unfinished">Cancella etichetta</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation type="unfinished">Mostra l&apos;etichetta</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation type="unfinished">Cambia l&apos;etichetta...</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation type="unfinished">&amp;Nascondi gli oggetti</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation type="unfinished">&amp;Rivisualizza tutto</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished">&amp;Colore</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation type="unfinished">Stile della retta</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation type="unfinished">&amp;Stile del punto</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="unfinished">&amp;Font</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation type="unfinished">Cambia &amp;Numero di campioni...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation type="unfinished">&amp;Altro...</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation type="unfinished">&amp;Font...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation type="unfinished">&amp;Punto di intersezione</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation type="unfinished">&amp;Segmento</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation type="unfinished">&amp;Punto medio</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation type="unfinished">&amp;Semiretta</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation type="unfinished">&amp;Retta</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation type="unfinished">&amp;Retta perpendicolare</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation type="unfinished">&amp;Cerchio di Centro e per il Punto</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation type="unfinished">&amp;Arco per tre Punti</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation type="unfinished">Bisettrice &amp;dell&apos;Angolo </translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation type="unfinished">Luogo</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation type="unfinished">Poligono</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation type="unfinished">S&amp;ettore Circolare</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation type="unfinished">Se&amp;gmento Circolare</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation type="unfinished">Interno del C&amp;erchio</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation type="unfinished">&amp;Distanza</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation type="unfinished">&amp;Lunghezza</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation type="unfinished">&amp;Raggio</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation type="unfinished">&amp;Angolo</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation type="unfinished">Ra&amp;pporto</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation type="unfinished">&amp;Pendenza</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation type="unfinished">Ar&amp;ea</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation type="unfinished">&amp;Calcola...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation type="unfinished">Scegli &amp;Vettore</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation type="unfinished">Scegli &amp;Rifletti</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation type="unfinished">Scegli &amp;Centro</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation type="unfinished">Scegli &amp;Angolo</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation type="unfinished">Scegli Rapporto</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation type="unfinished">Annulla scelti</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation type="unfinished">&amp;Traslazione</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation type="unfinished">R&amp;iflessione</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation type="unfinished">&amp;Omotetia</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation type="unfinished">&amp;Rotazione</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation type="unfinished">Rendi &amp;Normale</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation type="unfinished">Rendi &amp;Dato</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation type="unfinished">Rendi &amp;Finale</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation type="unfinished">Rendi &amp;Iniziale</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation type="unfinished">&amp;Ciclo ricorsivo</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation type="unfinished">&amp;Esegui direttamente</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation type="unfinished">&amp;Su...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation type="unfinished">&amp;Circonferenza</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation type="unfinished">Arco &amp;Lunghezza</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation type="unfinished">Scambia &amp;Etichette</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation type="unfinished">Cancella le etichette</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation type="unfinished">Mostra etichette</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation type="unfinished">&amp;Segmenti</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation type="unfinished">&amp;Semirette</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation type="unfinished">&amp;Punti medi</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation type="unfinished">&amp;Punti di Intersezione </translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation type="unfinished">&amp;Cerchio di Centro e Raggio</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation type="unfinished">&amp;Rette</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation type="unfinished">&amp;Rette Parallele</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation type="unfinished">&amp;Retta Parallela</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation type="unfinished">&amp;Rette Perpendicolari</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished">Senza titolo</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation type="unfinished">&amp;Cambia Directory...</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation type="unfinished">Nessuna Costruzione</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation type="unfinished">Salva?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation type="unfinished">Desideri salvare la modifiche?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation type="unfinished">File Non Trovato</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation type="unfinished">Spiacente, temo che il %1 non esista.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">File non valido</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation type="unfinished">Il file %1 non pare essere un file KSEG valido.</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation type="unfinished">Cambio di lingua</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation type="unfinished">Dovrai rilanciare KSEG perche&apos; il cambio della lingua abbia completamente effetto.</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation type="unfinished">Su KSEG</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation type="unfinished">&amp;Cancella l&apos;Oggetto</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation type="unfinished">&amp;Nascondi l&apos;oggetto</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation type="unfinished">Pr&amp;eferenze...</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation type="unfinished">Apri nella attuale Finestra...</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation type="unfinished">Copia come Costruzione</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation type="unfinished">Gruppi &amp;Selezionati...</translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation type="unfinished">KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished">&amp;Zoom</translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation type="unfinished">&amp;Spostamento</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished">&amp;Vista</translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation type="unfinished">Zoom per &amp;Riempire</translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation type="unfinished">Zoom &amp;Originale</translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation type="unfinished">E&amp;sportazione ad una immagine</translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation type="unfinished">Punti finali</translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation type="unfinished">Punto centrale</translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation type="unfinished">Punto finale</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation type="unfinished">Zoom</translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation type="unfinished">Scegli il formato del file</translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation type="unfinished">Immagine di alta qualita&apos;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation type="unfinished">Esportazione, attendere prego...</translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation type="unfinished">Righe:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation type="unfinished">Colonne:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation type="unfinished">Pieno-di-Zeri</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancella</translation>
    </message>
</context>
</TS>
